#ifndef MEMORYCARDSELECT_H
#define MEMORYCARDSELECT_H

#include <QDialog>
#include <QListWidgetItem>

namespace Ui {
    class MemoryCardSelect;
}

class MemoryCardSelect : public QDialog
{
    Q_OBJECT

public:
    explicit MemoryCardSelect(QWidget *parent = 0, QString selected="");
    ~MemoryCardSelect();
    QString Selected();

private:
    Ui::MemoryCardSelect *ui;
    QString m_Selected;

    QStringList m_List;
    void FillList();

private slots:
    void MemoryCardSelected(QListWidgetItem*);
};

#endif // MEMORYCARDSELECT_H
